@@ -6,8 +6,10 @@ import sys
 
 def main():
     os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'corgy_erp.settings')
+    os.environ.setdefault('DJANGO_CONFIGURATION', 'Development')
+
     try:
-        from django.core.management import execute_from_command_line
+        from configurations.management import execute_from_command_line
     except ImportError as exc:
         raise ImportError(
             "Couldn't import Django. Are you sure it's installed and "
